@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: gamadata.h,v 1.2 2007/06/26 15:04:05 cepek Exp $
+ *  $Id: gamadata.h,v 1.4 2008/04/13 10:02:31 cepek Exp $
  */ 
 
 #ifndef GaMaLib____ObservationData____and_other_data_objects___h_____
@@ -53,11 +53,11 @@ namespace GaMaLib {
   std::ostream& operator << (std::ostream&,     PointData&);
   std::ostream& operator << (std::ostream& str, ObservationData&);
 
-  inline bool Consistent(const PointData& lcs)
+  inline bool GaMaConsistent(const PointData& lcs)
     {
       return 
-        (lcs.right_handed_coordinates() &&  lcs.right_handed_angles) ||
-        (lcs. left_handed_coordinates() && !lcs.right_handed_angles) ; 
+        (lcs. left_handed_coordinates() &&  lcs.right_handed_angles) ||
+        (lcs.right_handed_coordinates() && !lcs.right_handed_angles) ; 
     }
 
 
