@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_model.h,v 1.3 2007/06/26 15:04:10 cepek Exp $
+ *  $Id: g3_model.h,v 1.5 2009/08/16 19:23:32 cepek Exp $
  */
 
 #ifndef GNU_gama__g3_model_h_gnugamag3modelh___gnu_gama_g3model
@@ -39,7 +39,12 @@
 #include <gnu_gama/e3.h>
 #include <list>
 
-namespace GNU_gama {  namespace g3 {
+namespace GNU_gama {  
+
+  /** \brief Adjustment model on ellipsoid */
+  namespace g3 {
+
+  /** g3 adjustment model. */
 
   class Model : public GNU_gama::Model<g3::Observation>
   {
@@ -110,6 +115,8 @@ namespace GNU_gama {  namespace g3 {
     double get_apriori_sd() const   { return apriori_sd;       } 
     void   set_conf_level(double c) { confidence_level = c;    }
     double get_conf_level() const   { return confidence_level; } 
+    void   set_tol_abs   (double c) { tol_abs = c;             }
+    double get_tol_abs   () const   { return tol_abs;          } 
 
     double standard_deviation() const { return std_deviation; }
     double standard_variance () const { return std_variance; }
@@ -189,6 +196,7 @@ namespace GNU_gama {  namespace g3 {
     // constants
     double apriori_sd;
     double confidence_level;
+    double tol_abs;
 
     bool   gons_;
 
