@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_model_linearization.cpp,v 1.3 2007/06/26 15:04:10 cepek Exp $
+ *  $Id: g3_model_linearization.cpp,v 1.5 2009/08/16 19:23:32 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_model.h>
@@ -118,6 +118,8 @@ void GNU_gama::g3::Model::update_linearization()
       
     } while (!check_observations());
   
+  if (dm_floats * dm_rows * dm_cols == 0)
+    throw GNU_gama::Exception::string("No parameters and/or observations");
 
   adj_input_data->set_mat(A);
   adj_input_data->set_rhs(rhs);
@@ -405,7 +407,7 @@ void Model::linearization(Distance* d)
 
     double rd = rhs(++rhs_ind) = (d->obs() - D)*Linear().scale();
 
-    if (abs(rd) > 1e3)
+    if (abs(rd) > tol_abs)
       {
         Model::Rejected robs;
         
@@ -510,7 +512,7 @@ void Model::linearization(Vector* v)
      rhs(++rhs_ind) = ry = (v->dy() - dy)*s;
      rhs(++rhs_ind) = rz = (v->dz() - dz)*s;
 
-     if (abs(rx) > 1e3 || abs(ry) > 1e3 || abs(rz) > 1e3)
+     if (abs(rx) > tol_abs || abs(ry) > tol_abs || abs(rz) > tol_abs)
        {
          Model::Rejected robs;
 
@@ -570,7 +572,7 @@ void Model::linearization(XYZ* xyz)
      rhs(++rhs_ind) = ry = (xyz->y() - y)*s;
      rhs(++rhs_ind) = rz = (xyz->z() - z)*s;
 
-     if (abs(rx) > 1e3 || abs(ry) > 1e3 || abs(rz) > 1e3)
+     if (abs(rx) > tol_abs || abs(ry) > tol_abs || abs(rz) > tol_abs)
        {
          Model::Rejected robs;
 
