@@ -6,7 +6,7 @@
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: localnetwork_adjustment_results.cpp,v 1.3 2006/05/14 11:06:24 cepek Exp $
+ *  $Id: localnetwork_adjustment_results.cpp,v 1.9 2007/06/26 15:04:11 cepek Exp $
  */
 
 
@@ -36,6 +36,21 @@ using namespace std;
 using namespace GNU_gama;
 
 
+double LocalNetworkAdjustmentResults::Observation::residual() const
+  throw()
+{
+  double r = (adj - obs);
+  if (xml_tag == "direction" || xml_tag == "angle" || 
+      xml_tag == "zenith-angle")
+    {
+      if (r >= 400 || std::abs(r - 400) < std::abs(r)) r -= 400;
+      r *= 10;
+    }
+
+  return r*1000;
+}
+
+
 void LocalNetworkAdjustmentResults::read_xml(std::istream& xml)
   throw(GNU_gama::Exception::parser)
 {
@@ -132,17 +147,23 @@ void LocalNetworkAdjustmentResults::Parser::init()
   tagfun[s_ors_approx_end                     ][t_adj                            ] = &Parser::ors_adj;
   tagfun[s_orientation_shifts_end             ][t_cov_mat                        ] = &Parser::cov_mat;
   tagfun[s_cov_mat                            ][t_dim                            ] = &Parser::dim;
+  tagfun[s_cov_mat_end                        ][t_original_index                 ] = &Parser::original_index;
   tagfun[s_dim_end                            ][t_band                           ] = &Parser::band;
   tagfun[s_flt_end                            ][t_flt                            ] = &Parser::flt;
+  tagfun[s_original_index                     ][t_ind                            ] = &Parser::ind;
+  tagfun[s_ind_end                            ][t_ind                            ] = &Parser::ind;
   tagfun[s_coordinates_end                    ][t_observations                   ] = &Parser::observations;
   tagfun[s_observation                        ][t_from                           ] = &Parser::from;
   tagfun[s_from_end                           ][t_to                             ] = &Parser::to;
   tagfun[s_from_end                           ][t_left                           ] = &Parser::left;
   tagfun[s_left_end                           ][t_right                          ] = &Parser::right;
   tagfun[s_to_end                             ][t_obs                            ] = &Parser::obs;
+  tagfun[s_observation                        ][t_id                             ] = &Parser::obs_id;
+  tagfun[s_obs_id_end                         ][t_obs                            ] = &Parser::obs;
   tagfun[s_obs_end                            ][t_adj                            ] = &Parser::obs_adj;
   tagfun[s_obs_adj_end                        ][t_stdev                          ] = &Parser::stdev;
-  tagfun[s_stdev_end                          ][t_f                              ] = &Parser::obs_f;
+  tagfun[s_stdev_end                          ][t_qrr                            ] = &Parser::obs_qrr;
+  tagfun[s_obs_qrr_end                        ][t_f                              ] = &Parser::obs_f;
   tagfun[s_obs_f_end                          ][t_std_residual                   ] = &Parser::std_residual;
   tagfun[s_std_residual_end                   ][t_err_obs                        ] = &Parser::err_obs;
   tagfun[s_err_obs_end                        ][t_err_adj                        ] = &Parser::err_adj;
@@ -237,6 +258,7 @@ int LocalNetworkAdjustmentResults::Parser::tag(const char* c)
       break;
     case 'i':
       if (!strcmp(c, "id"                        )) return t_id;
+      if (!strcmp(c, "ind"                       )) return t_ind;
       break;
     case 'l':
       if (!strcmp(c, "left"                      )) return t_left;
@@ -252,6 +274,7 @@ int LocalNetworkAdjustmentResults::Parser::tag(const char* c)
       if (!strcmp(c, "observations-summary"      )) return t_observations_summary;
       if (!strcmp(c, "orientation-shifts"        )) return t_orientation_shifts;
       if (!strcmp(c, "orientation"               )) return t_orientation;
+      if (!strcmp(c, "original-index"            )) return t_original_index;
       break;
     case 'p':
       if (!strcmp(c, "passed"                    )) return t_passed;
@@ -259,6 +282,9 @@ int LocalNetworkAdjustmentResults::Parser::tag(const char* c)
       if (!strcmp(c, "probability"               )) return t_probability;
       if (!strcmp(c, "project-equations"         )) return t_project_equations;
       break;
+    case 'q':
+      if (!strcmp(c, "qrr"                       )) return t_qrr;
+      break;
     case 'r':
       if (!strcmp(c, "ratio"                     )) return t_ratio;
       if (!strcmp(c, "right"                     )) return t_right;
@@ -389,7 +415,13 @@ void LocalNetworkAdjustmentResults::Parser::network_general_parameters(bool star
           string atr = *attributes++;
           string val = *attributes++;
 
-          if (atr == "epoch") 
+          if (atr == "gama-local-version") 
+            adj->network_general_parameters.gama_local_version = val;
+          else if (atr == "gama-local-algorithm") 
+            adj->network_general_parameters.gama_local_algorithm = val;
+          else if (atr == "gama-local-compiler") 
+            adj->network_general_parameters.gama_local_compiler = val;
+          else if (atr == "epoch") 
             adj->network_general_parameters.epoch = val;
           else if (atr == "axes-xy") 
             adj->network_general_parameters.axes_xy = val;
@@ -1100,6 +1132,21 @@ void LocalNetworkAdjustmentResults::Parser::id(bool start)
 }
 
 
+void LocalNetworkAdjustmentResults::Parser::obs_id(bool start)
+{
+  if (start)
+    {
+      stack.push(&Parser::obs_id);
+      set_state(s_obs_id);
+    }
+  else
+    {
+      tmp_obs.from = get_string();
+      set_state(s_obs_id_end);
+    }
+}
+
+
 void LocalNetworkAdjustmentResults::Parser::x(bool start)
 {
   if (start)
@@ -1227,6 +1274,23 @@ void LocalNetworkAdjustmentResults::Parser::cov_mat(bool start)
 }
 
 
+void LocalNetworkAdjustmentResults::Parser::original_index(bool start)
+{
+  if (start)
+    {
+      adj->original_index.clear();
+      adj->original_index.push_back(-1);  // indexing from 1
+
+      stack.push(&Parser::original_index);
+      set_state(s_original_index);
+    }
+  else
+    {
+      set_state(s_original_index_end);
+    }
+}
+
+
 void LocalNetworkAdjustmentResults::Parser::dim(bool start)
 {
   if (start)
@@ -1277,6 +1341,21 @@ void LocalNetworkAdjustmentResults::Parser::flt(bool start)
 }
 
 
+void LocalNetworkAdjustmentResults::Parser::ind(bool start)
+{
+  if (start)
+    {
+      stack.push(&Parser::ind);
+      set_state(s_ind);
+    }
+  else
+    {
+      adj->original_index.push_back( get_int() );
+      set_state(s_ind_end);
+    }
+}
+
+
 void LocalNetworkAdjustmentResults::Parser::observations(bool start)
 {
   if (start)
@@ -1304,7 +1383,9 @@ void LocalNetworkAdjustmentResults::Parser::observation(bool start)
     }
   else
     {
-      if (state != s_err_adj_end) error("observation attribute(s) missing");
+      if (state != s_obs_f_end        && 
+          state != s_std_residual_end &&
+          state != s_err_adj_end        ) error("observation attribute(s) missing");
       adj->obslist.push_back(tmp_obs);
       set_state(s_observations);
     }
@@ -1416,6 +1497,21 @@ void LocalNetworkAdjustmentResults::Parser::stdev(bool start)
 }
 
 
+void LocalNetworkAdjustmentResults::Parser::obs_qrr(bool start)
+{
+  if (start)
+    {
+      stack.push(&Parser::obs_qrr);
+      set_state(s_obs_qrr);
+    }
+  else
+    {
+      tmp_obs.qrr = get_float();
+      set_state(s_obs_qrr_end);
+    }
+}
+
+
 void LocalNetworkAdjustmentResults::Parser::obs_f(bool start)
 {
   if (start)
@@ -1440,7 +1536,7 @@ void LocalNetworkAdjustmentResults::Parser::std_residual(bool start)
     }
   else
     {
-      tmp_obs.std_residual = get_string();
+      tmp_obs.std_residual = get_float();
       set_state(s_std_residual_end);
     }
 }
